summaryrefslogtreecommitdiffstats
path: root/kmymoney2/kstartuplogo.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/kstartuplogo.cpp')
-rw-r--r--kmymoney2/kstartuplogo.cpp36
1 files changed, 18 insertions, 18 deletions
diff --git a/kmymoney2/kstartuplogo.cpp b/kmymoney2/kstartuplogo.cpp
index 566f8ad..a0d8ac6 100644
--- a/kmymoney2/kstartuplogo.cpp
+++ b/kmymoney2/kstartuplogo.cpp
@@ -19,10 +19,10 @@
// ----------------------------------------------------------------------------
// QT Includes
-#include <qapplication.h>
-#include <qpixmap.h>
-#include <qframe.h>
-#include <qpainter.h>
+#include <tqapplication.h>
+#include <tqpixmap.h>
+#include <tqframe.h>
+#include <tqpainter.h>
// ----------------------------------------------------------------------------
// KDE Includes
@@ -41,12 +41,12 @@
class KStartupSplash::Private
{
public:
- QString message;
- QColor color;
+ TQString message;
+ TQColor color;
int align;
};
-KStartupSplash::KStartupSplash(const QPixmap &pixmap, WFlags f) :
+KStartupSplash::KStartupSplash(const TQPixmap &pixmap, WFlags f) :
KSplashScreen(pixmap, f),
d(new Private)
{
@@ -57,39 +57,39 @@ KStartupSplash::~KStartupSplash()
delete d;
}
-void KStartupSplash::message( const QString &message, int alignment, const QColor &color)
+void KStartupSplash::message( const TQString &message, int tqalignment, const TQColor &color)
{
d->message = message;
- d->align = alignment;
+ d->align = tqalignment;
d->color = color;
// the next line causes the base class signal management to happen
// and also forces a repaint
KSplashScreen::clear();
}
-void KStartupSplash::drawContents( QPainter *painter )
+void KStartupSplash::drawContents( TQPainter *painter )
{
painter->setPen( d->color );
- QRect r = rect();
+ TQRect r = rect();
r.setRect( r.x() + 15, r.y() + r.height() - 28, r.width() - 20, 20 );
painter->drawText( r, d->align, d->message);
}
KStartupLogo::KStartupLogo() :
- QObject(0, 0),
+ TQObject(0, 0),
m_splash(0)
{
// splash screen setting
if(!KMyMoneyGlobalSettings::showSplash())
return;
- QString filename = KGlobal::dirs()->findResource("appdata", "pics/startlogo.png");
- QPixmap splashPixmap(filename);
+ TQString filename = KGlobal::dirs()->findResource("appdata", "pics/startlogo.png");
+ TQPixmap splashPixmap(filename);
if(!splashPixmap.isNull()) {
- QPixmap backGround(splashPixmap);
+ TQPixmap backGround(splashPixmap);
backGround.fill(KGlobalSettings::highlightColor());
- bitBlt ( &backGround, 0, 0, &splashPixmap, 0, 0, splashPixmap.width(), splashPixmap.height(), Qt::CopyROP );
+ bitBlt ( &backGround, 0, 0, &splashPixmap, 0, 0, splashPixmap.width(), splashPixmap.height(), TQt::CopyROP );
KStartupSplash* splash = new KStartupSplash(backGround);
splash->setFixedSize(backGround.size());
@@ -100,7 +100,7 @@ KStartupLogo::KStartupLogo() :
splash->message(i18n("Loading..."), AlignLeft, white);
splash->show();
- splash->repaint();
+ splash->tqrepaint();
m_splash = splash;
}
}
@@ -57,39 +57,39 @@ KStartupSplash::~KStartupSplash()
d->color = color;
// the next line causes the base class signal management to happen
- // and also forces a repaint
+ // and also forces a tqrepaint
KSplashScreen::clear();
}